@@ -21,4 +21,6 @@
 # IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__version__ = "0.0.0"
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution("python-keycloak").version
